import React from 'react'
import { CustomFoodCard, CustomFoodCardNew } from './FoodCard.style'
import CustomImageContainer from '../CustomImageContainer'
import test_image from '../../../public/static/testImage.svg'
import { CustomStackForFoodModal } from '../foodDetail-modal/FoodModalStyle'
import { Button, Chip, IconButton, Typography } from '@mui/material'
import ProductCardMedia from './ProductCardMedia'
import VagSvg from '../foodDetail-modal/VagSvg'
import { Stack } from '@mui/system'
import { useTheme } from '@mui/material/styles'
import { CustomStackFullWidth } from '../../styled-components/CustomStyles.style'
import { CustomTypographyGray } from '../error/Errors.style'
import StartPriceView from '../foodDetail-modal/StartPriceView'
import AddIcon from '@mui/icons-material/Add'
import { useSelector } from 'react-redux'
import { CustomTypographyEllipsis } from '../../styled-components/CustomTypographies.style'
import AfterAddToCart from './AfterAddToCart'
import { Divider } from '@material-ui/core'
import { useTranslation } from 'react-i18next'
import { RTL } from '../RTL/RTL'
const FoodVerticalCard = (props) => {
    const {
        product,
        setOpenModal,
        productImageUrl,
        handleFoodDetailModal,
        deleteWishlistItem,
        isInList,
        addToFavorite,
        imageUrl,
        handleBadge,
        addToCart,
        isInCart,
        getQuantity,
        incrOpen,
        setIncrOpen,
        handleClickQuantityButton,
        hasBackGroundSection,
    } = props

    let currencySymbol
    let currencySymbolDirection
    let digitAfterDecimalPoint
    const languageDirection = localStorage.getItem('direction')

    const { global } = useSelector((state) => state.globalSettings)

    if (global) {
        currencySymbol = global.currency_symbol
        currencySymbolDirection = global.currency_symbol_direction
        digitAfterDecimalPoint = global.digit_after_decimal_point
    }
    const theme = useTheme()
    const { t } = useTranslation()

    // console.log('languageDirection: ' + languageDirection)
    return (
        <RTL direction={languageDirection ?? 'rtl'}>
            <CustomFoodCardNew
                sx={{ direction: languageDirection ?? 'rtl', width: '100%' }}
                maxwidth="240px"
                smheight="240px"
                height="310px"
                onClick={(e) => handleFoodDetailModal(e)}
                background={
                    hasBackGroundSection === 'true'
                        ? theme.palette.cardBackground1
                        : theme.palette.cardBackground2
                }
            >
                <CustomStackFullWidth spacing={1.3}>
                    <ProductCardMedia
                        imageUrl={imageUrl}
                        avg_rating={product?.avg_rating}
                        discount={product?.discount}
                        discount_type={product?.discount_type}
                        restaurant_discount={product?.restaurant_discount}
                        alt={name}
                        price={product?.price}
                        onClick={handleFoodDetailModal}
                        available_time_ends={product?.available_time_ends}
                        available_time_starts={product?.available_time_starts}
                        available_date_ends={product?.available_date_ends}
                        deleteWishlistItem={deleteWishlistItem}
                        isInList={isInList}
                        addToFavorite={addToFavorite}
                        id={product?.id}
                        deliveryTime={product?.delivery_time}
                        minFreeDelivery={product?.min_delivery_time}
                        maxFreeDelivery={product?.max_delivery_time}
                        handleBadge={handleBadge}
                        product={product}
                    />
                    <CustomStackFullWidth sx={{ padding: '5px' }}>
                        <Stack
                            direction="row"
                            justifyContent="center"
                            alignItems="center"
                            flexWrap="wrap"
                            spacing={0.5}
                        >
                            {/* {!product?.available_date_ends &&
                            handleBadge(
                                product,
                                currencySymbol,
                                currencySymbolDirection,
                                digitAfterDecimalPoint
                            )} */}
                            <CustomTypographyEllipsis
                                variant="h5"
                                fontWeight="500"
                                justifyContent={'center'}
                                sx={{
                                    marginX: 'auto',
                                    maxWidth: '163px',
                                    [theme.breakpoints.down('md')]: {
                                        maxWidth: '112px',
                                    },
                                }}
                            >
                                {product?.name}
                            </CustomTypographyEllipsis>
                        </Stack>

                        <div
                            style={{
                                overflow: 'hidden',
                                textOverflow: 'ellipsis',
                                whiteSpace: 'nowrap',
                                display: 'flex',
                                flexDirection: 'row',
                                marginTop: '3px',
                                width: '100%',
                            }}
                        >
                            {product?.cuisines?.length > 0 &&
                                product?.cuisines?.map((cuisine, index) => (
                                    <Typography
                                        align="left"
                                        fontSize="12px"
                                        color={theme.palette.neutral[600]}
                                    >
                                        {cuisine?.name}
                                        {product?.cuisines?.length - 1 === index
                                            ? ''
                                            : ','}
                                    </Typography>
                                ))}
                        </div>

                        <Stack
                            width="100%"
                            justifyContent="start"
                            direction="row"
                            alignItems="center"
                            position="relative"
                            mt={{ xs: '0px', sm: '2px', md: '4px' }}
                        >
                            <StartPriceView
                                data={product}
                                handleBadge={handleBadge}
                                available_date_ends={
                                    product?.available_date_ends
                                }
                            />
                        </Stack>
                        <Stack height={5} />

                        <Divider
                            variant="fullWidth"
                            component="h1"
                            sx={{
                                borderTop: `5px solid ${theme.palette.primary.main}`,
                                height: '10px',
                                fontSize: '10px',
                            }}
                        />

                        <Stack
                            width="100%"
                            justifyContent="space-between"
                            direction="row"
                            alignItems="center"
                            position="relative"
                            mt={{ xs: '0px', sm: '2px', md: '4px' }}
                        >
                            {!isInCart && (
                                <Button
                                    fullWidth
                                    variant="text"
                                    onClick={(e) => addToCart(e)}
                                    sx={{
                                        padding: '3px',
                                        textTransform: 'none',
                                        display: 'flex',
                                        justifyContent: 'space-around',
                                    }}
                                >
                                      <AddIcon
                                        sx={{ marginRight: '8px' }} 
                                        fontSize="large"
                                        color="primary"
                                    />
                                    <Typography
                                        align="left"
                                        fontSize="12px"
                                        fontWeight="bold"
                                        color={theme.palette.neutral[600]}
                                    >
                                        {t('Add to cart')}
                                    </Typography>
                                  
                                </Button>
                            )}

                            {isInCart && (
                                <AfterAddToCart
                                    isInCart={isInCart}
                                    product={product}
                                    getQuantity={getQuantity}
                                    handleClickQuantityButton={
                                        handleClickQuantityButton
                                    }
                                    setIncrOpen={setIncrOpen}
                                    incrOpen={incrOpen}
                                />
                            )}
                        </Stack>
                    </CustomStackFullWidth>
                </CustomStackFullWidth>
            </CustomFoodCardNew>
        </RTL>
    )
}

export default FoodVerticalCard
