import React, { memo, useEffect, useRef, useState } from 'react'
import { useSelector } from 'react-redux'
import CategoryView from './category-view/CategoryView'
import { useGetAllProductsOfARestaurant } from '../../hooks/custom-hooks/useGetAllProductsOfARestaurant'
import { Skeleton } from '@mui/material'
import { Stack } from 'react-bootstrap'
import { SliderCustom } from '../../styled-components/CustomStyles.style'
import Slider from 'react-slick'
import { settings } from './category-view/SliderSetting'
import FoodCardShimmer from '../food-card/FoodCarShimmer'

const getCombinedCategoriesAndProducts = (all_categories, all_products) => {
    const allCategories = all_categories
    const allProducts = all_products

    if (allCategories?.length > 0 && allProducts?.length > 0) {
        const data = allCategories?.map((item) => {
            const categoryItems = allProducts?.filter(
                (product) => product?.category_ids[0]?.id == item?.id
            )
            if (categoryItems.length > 0) {
                return {
                    ...item,
                    products: categoryItems,
                }
            } else {
                return {
                    ...item,

                    products: [],
                }
            }
        })
        return data
    } else {
        return []
    }
}

const CategoriesView = ({ isLoading, restaurantId }) => {
    const { featuredCategories } = useSelector((state) => state.storedData)
    // set restaurant as static for get restaurant's products
    const allProducts = useGetAllProductsOfARestaurant(2)
    const [data, setData] = useState()
    useEffect(() => {
        const combined = getCombinedCategoriesAndProducts(
            featuredCategories,
            allProducts
        )
        const hasProducts = combined?.filter(
            (item) => item?.products?.length > 0
        )
        setData(hasProducts)
        // console.log('the restaurant is', hasProducts)
    }, [isLoading, allProducts])

    if (isLoading || !data?.length > 0)
        return (
            <Stack marginTop="40px" spacing={2}>
                <Skeleton variant="rectangular" width="400px" height="20px" />
                <SliderCustom>
                    <Slider {...settings}>
                        <FoodCardShimmer />
                        <FoodCardShimmer />
                        <FoodCardShimmer />
                        <FoodCardShimmer />
                        <FoodCardShimmer />
                    </Slider>
                </SliderCustom>
            </Stack>
        )
    return (
        <>
            {featuredCategories && featuredCategories.length > 4 && (
                <>
                    {data.map((item, index) => {
                        return (
                            <CategoryView
                                key={item?.id}
                                isLoading={isLoading}
                                id={item?.id}
                                name={item?.name}
                                products={item?.products}
                            />
                        )
                    })}
                </>
            )}
        </>
    )
}

export default memo(CategoriesView)
