import { useQuery } from 'react-query'
import 'slick-carousel/slick/slick.css'
import 'slick-carousel/slick/slick-theme.css'

import {
    Grid,
    IconButton,
    Typography,
    useMediaQuery,
    Stack,
    Skeleton,
} from '@mui/material'
import {
    CustomStackFullWidth,
    CustomViewAll,
    SliderCustom,
} from '../../../styled-components/CustomStyles.style'
import Slider from 'react-slick'
import { useTheme } from '@mui/material/styles'
import { useSelector } from 'react-redux'
import { CategoryApi } from '../../../hooks/react-query/config/categoryApi'
import FoodCard from '../../food-card/FoodCard'
import CustomShimmerForBestFood from '../../CustomShimmer/CustomShimmerForBestFood'
import { settings } from './SliderSetting'
import { useTranslation } from 'react-i18next'
import KeyboardArrowRightIcon from '@mui/icons-material/KeyboardArrowRight'
import Router, { useRouter } from 'next/router'
import { RTL } from '../../RTL/RTL'
export default function RaowdalaseelBanner({ id, name }) {
    const languageDirection = localStorage.getItem('direction')
    const theme = useTheme()
    const { t } = useTranslation()
    const router = useRouter()
    const isXSmall = useMediaQuery(theme.breakpoints.up('sm'))
    const matchesToMd = useMediaQuery('(max-width:1200px)')
    const { global } = useSelector((state) => state.globalSettings)
    const {
        isLoading: fetchingRaowdalaseelProduct,
        data: raowdalaseelProductData,
        isError,
        error,
        refetch: refetchRaowdalaseelProductData,
    } = useQuery([`raowdalaseel-product-${id}`], () =>
        CategoryApi.categoriesDetails(id, 'all', '1', `${id}`)
    )

    const handleClick = () => {
   
        Router.push(
            {
                pathname: `/category/${id}`,
                query: { name: name },
            },
            undefined,
            { shallow: true }
        )
    }

    if (id === 19) {
        // console.log(raowdalaseelProductData?.data?.products)
    }
    return (
        <Stack spacing={2}>
            {/* <Skeleton variant="rectangular" width="400px" height="20px" /> */}
            {raowdalaseelProductData?.data?.products?.length > 0 && (
                <Grid item xs={12} md={12}>
                    <CustomStackFullWidth
                        direction="row"
                        alignItems="center"
                        justifyContent="space-between"
                    >
                        <Stack direction="row" spacing={1}>
                            <Typography
                                variant="h3"
                                color={theme.palette.neutral[1000]}
                                fontWeight="500"
                            >
                                {name}
                            </Typography>
                        </Stack>

                        <CustomViewAll
                            onClick={handleClick}
                            direction="row"
                            spacing={1}
                            alignItems="center"
                        >
                            {isXSmall && (
                                <Typography>{t('View all')}</Typography>
                            )}

                            <IconButton
                                sx={{
                                    filter: 'drop-shadow(0px 1px 3px rgba(0, 0, 0, 0.1))',
                                    flex: 'none',
                                    order: '1',
                                    flexGrow: '0',
                                    boxShadow: 3,
                                }}
                            >
                                <KeyboardArrowRightIcon
                                    color="primary"
                                    style={{
                                        width: '19px',
                                        height: '19px',
                                        transform:
                                            languageDirection === 'rtl' &&
                                            'rotate(180deg)',
                                    }}
                                    fontWeight="700"
                                />
                            </IconButton>
                        </CustomViewAll>
                    </CustomStackFullWidth>
                </Grid>
            )}

            {id !== 19 && raowdalaseelProductData?.data && (
                <SliderCustom>
                    <Slider {...settings}>
                        {raowdalaseelProductData?.data?.products?.map(
                            (product, index) => {
                                if (
                                    product?.variations === null ||
                                    product?.variations[0]?.values ||
                                    product?.variations?.length === 0
                                ) {
                                    return (
                                        <RTL
                                            direction={languageDirection}
                                            key={product?.id}
                                        >
                                            <Grid
                                                key={product?.id}
                                                item
                                                md={matchesToMd ? 3 : 2.4}
                                                sm={4}
                                                xs={6}
                                            >
                                                <FoodCard
                                                    key={index}
                                                    product={product}
                                                    productImageUrl={
                                                        global?.base_urls
                                                            ?.product_image_url
                                                    }
                                                />
                                            </Grid>
                                        </RTL>
                                    )
                                }
                            }
                        )}
                    </Slider>
                </SliderCustom>
            )}
            {id === 19 && raowdalaseelProductData?.data && (
                <Grid container gap={'10px'}>
                    {raowdalaseelProductData?.data?.products?.map(
                        (product, index) => {
                            return (
                                <Grid>
                                    <FoodCard
                                        key={index}
                                        product={product}
                                        productImageUrl={
                                            global?.base_urls.product_image_url
                                        }
                                    />
                                </Grid>
                            )
                        }
                    )}
                </Grid>
            )}
        </Stack>
    )
}
