// components/Category.js
import React from 'react'
import { Card, CardContent, Typography } from '@mui/material'
import { makeStyles } from '@mui/styles'
import Router from 'next/router'
import Image from 'next/image'

const useStyles = makeStyles({
    categoryCard: {
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        padding: '12px', // Smaller padding
        borderRadius: '8px',
        boxShadow: '0 2px 4px rgba(0, 0, 0, 0.1)', // Smaller shadow
        transition: 'background-color 0.3s ease-in-out',
        cursor: 'pointer',
        '&:hover': {
            backgroundColor: '#f0f0f0', // Lighter background on hover
            transition: 'scale(2)',
        },
        // width: '120px', // Fixed width
    },
    image: {
        width: 'auto', // Adjusted width
        height: 'auto', // Adjusted height
        borderRadius: '50%',
        '&:hover': {
            backgroundColor: '#f0f0f0', // Lighter background on hover
            transition: 'scale(1.1)',
        },
    },
    name: {
        textAlign: 'center',
        marginTop: '8px', // Smaller top margin
        fontSize: '14px', // Smaller font size
        fontWeight: 'bold',
        color: '#333',
    },
})

const Category = ({ imageUrl, name, backgroundColor, id }) => {
    const classes = useStyles()

    const handleClick = () => {
        Router.push(
            {
                pathname: `/category/${id}`,
                query: { name: name },
            },
            undefined,
            { shallow: true }
        )
    }

    return (
        <div>
            <Card
                className={classes.categoryCard}
                style={{ backgroundColor }}
                onClick={handleClick}
            >
                <Image
                    width={120} // Set your desired width
                    height={120} // Set your desired height
                    src={imageUrl}
                    alt={name}
                    className={classes.image}
                />
            </Card>
            <Typography className={classes.name}>{name}</Typography>
        </div>
    )
}

export default Category
